package com.example.wholeestate.service.impl;

import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.example.wholeestate.common.resp.ResponseBean;
import com.example.wholeestate.common.uuid.IdGen;
import com.example.wholeestate.dao.AppointmentMapper;
import com.example.wholeestate.dao.BuildingImgMapper;
import com.example.wholeestate.dao.BuildingMapper;
import com.example.wholeestate.dao.CustomerMapper;
import com.example.wholeestate.model.Appointment;
import com.example.wholeestate.model.Building;
import com.example.wholeestate.model.BuildingImg;
import com.example.wholeestate.model.Customer;
import com.example.wholeestate.service.IBuildingService;
import com.fasterxml.jackson.databind.util.ArrayBuilders;
import com.sun.org.apache.bcel.internal.generic.NEW;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.time.LocalDateTime;
import java.util.ArrayList;
import java.util.Date;
import java.util.HashMap;
import java.util.List;

/**
 * <p>
 * 楼盘表 服务实现类
 * </p>
 *
 * @author jobob
 * @since 2019-03-20
 */
@Service
public class BuildingServiceImpl extends ServiceImpl<BuildingMapper, Building> implements IBuildingService {
    @Autowired
    private BuildingMapper buildingMapper;

    @Autowired
    private AppointmentMapper AppointmentMapper;

    @Autowired
    private  CustomerMapper customerMapper;

    @Autowired
    private BuildingImgMapper buildingImgMapper;
    private IdGen idGen = IdGen.get();

    @Override
    public ResponseBean buildingList(Integer pageNum,Integer pageSize,String name,String code) {
        ResponseBean response= new ResponseBean();
        Page<Building> page = new Page<>();
        page.setSize(pageSize == null ? 10 : pageSize);
        page.setCurrent(pageNum == null ? 1 : pageNum);
         IPage<Building> building= buildingMapper.buildingList(page,name,code);
        List<Building> buildingList=building.getRecords();

        HashMap hashMap= new HashMap<>();
        hashMap.put("list",buildingList);
        hashMap.put("total",building.getTotal());
        hashMap.put("pageNum",building.getCurrent());
        hashMap.put("pageSize",building.getSize());
        response.addSuccess(hashMap);
        return response;
    }

    @Override
    public ResponseBean buildingSelectId(String id) {
        ResponseBean response= new ResponseBean();
        QueryWrapper<Building> buildingtWrapper = new QueryWrapper<>();
        buildingtWrapper.lambda().eq(Building::getStatus,0);
        buildingtWrapper.lambda().eq(Building::getBuildingId,id);
        Building building= buildingMapper.selectOne(buildingtWrapper);
        response.addSuccess(building);
        return response;
    }

    @Override
    public ResponseBean buildingUpdate(String parameter) {
        ResponseBean response= new ResponseBean();

        JSONObject object= JSONObject.parseObject(parameter);

        Building building = JSONObject.parseObject(parameter,Building.class);
        String imgStr = object.getString("img");
        List<BuildingImg> buildingImgs = JSONObject.parseArray(imgStr, BuildingImg.class);

        QueryWrapper<Building> buildingIdQueryWrapper = new QueryWrapper<>();
        buildingIdQueryWrapper.eq("building_id", building.getBuildingId());
        buildingMapper.update(building,buildingIdQueryWrapper);
        //图片先删除再添加
        QueryWrapper<BuildingImg> BuildingImgQueryWrapper = new QueryWrapper<>();
        BuildingImgQueryWrapper.eq("building_id", building.getBuildingId());
        buildingImgMapper.delete(BuildingImgQueryWrapper);

        for (BuildingImg img:buildingImgs){
            BuildingImg Images = new BuildingImg();
            Images.setImgId(idGen.nextId()+"");
            Images.setBuildingId(building.getBuildingId());
            Images.setImgType(img.getImgType());
            Images.setUrl(img.getUrl());
            Images.setOrderNo(Integer.valueOf(img.getOrderNo()));
            Images.setStatus(0);
            Images.setCreateDate(LocalDateTime.now());
            buildingImgMapper.insert(Images);
        }



        response.addSuccess("成功");
        return response;
    }

    @Override
    public ResponseBean appointmentList(Integer pageNum,Integer pageSize,Integer buildingId,String username) {
        ResponseBean response= new ResponseBean();
        Page<Appointment> page = new Page<>();
        page.setSize(pageSize == null ? 10 : pageSize);
        page.setCurrent(pageNum == null ? 1 : pageNum);
        IPage<Appointment> building= AppointmentMapper.appendableList(page,buildingId,username);
        List<Appointment> buildingList=building.getRecords();
        //预约的用户，
        ArrayList  arrayListUser= new ArrayList<>();

        //预约的楼盘，
        ArrayList  arrayListbuilding= new ArrayList<>();
       for (Appointment bui:buildingList){
          Building buil= new Building();
           QueryWrapper<Building> buildingtWrapper = new QueryWrapper<>();
           buildingtWrapper.lambda().eq(Building::getStatus,0);
           buildingtWrapper.lambda().eq(Building::getBuildingId,bui.getBuildingId());
           Building bu= buildingMapper.selectOne(buildingtWrapper);
           arrayListUser.add(bu);

           QueryWrapper<Customer> customerWrapper = new QueryWrapper<>();
           customerWrapper.lambda().eq(Customer::getStatus,0);
           customerWrapper.lambda().eq(Customer::getCustomerId,bui.getCustomerId());
           Customer cust= customerMapper.selectOne(customerWrapper);
           arrayListbuilding.add(cust);

           bui.setArrayListUser(arrayListUser);
           bui.setArrayListbuilding(arrayListbuilding);
       }

        HashMap hashMap= new HashMap<>();
        hashMap.put("list",buildingList);
        hashMap.put("total",building.getTotal());
        hashMap.put("pageNum",building.getCurrent());
        hashMap.put("pageSize",building.getSize());
        response.addSuccess(hashMap);
        return response;
    }

    @Override
    public ResponseBean buildingAdd(String parameter) {
            ResponseBean response= new ResponseBean();

            JSONObject object= JSONObject.parseObject(parameter);

        Building building = JSONObject.parseObject(parameter,Building.class);
        String imgStr = object.getString("img");
        List<BuildingImg> buildingImgs = JSONObject.parseArray(imgStr, BuildingImg.class);
//            if (!"".equals(building.getBuildingId())&&null!=building.getBuildingId()){
//                response.addError("楼盘名称不能为空");
//                return response;
//            }
//            if (!"".equals(building.getPrice())&&null!=building.getPrice()){
//                response.addError("价格不能为空");
//                return response;
//            }
//            if (!"".equals(building.getOpeningDate())&&null!=building.getOpeningDate()){
//                response.addError("开盘时间");
//                return response;
//            }
            building.setBuildingId(idGen.nextId()+"");
            building.setOpeningDate(object.getDate("openingDate"));
            building.setCreateDate(LocalDateTime.now());
            building.setStatus(0);
        for (BuildingImg img:buildingImgs){
            BuildingImg Images = new BuildingImg();
            Images.setImgId(idGen.nextId()+"");
            Images.setBuildingId(building.getBuildingId());
            Images.setImgType(img.getImgType());
            Images.setUrl(img.getUrl());
            Images.setOrderNo(Integer.valueOf(img.getOrderNo()));
            Images.setStatus(0);
            Images.setCreateDate(LocalDateTime.now());
            buildingImgMapper.insert(Images);
        }
            buildingMapper.insert(building);




            response.addSuccess("成功");
            return response;
        }

    @Override
    public ResponseBean buildingUpdateStatus(String parameter) {
        Building  building= new Building();
        JSONObject jsonobject = JSONObject.parseObject(parameter);
        Integer  status= jsonobject.getInteger("status");
        String id= jsonobject.getString("id");
        QueryWrapper<Building> buildingIdQueryWrapper = new QueryWrapper<>();
        buildingIdQueryWrapper.eq("building_id", id);
        building.setBuildingId(id);
        building.setStatus(status);
        buildingMapper.update(building,buildingIdQueryWrapper);
         ResponseBean ResponseBean= new ResponseBean<>();
        ResponseBean.addSuccess("成功");
        return ResponseBean;
    }

    @Override
    public ResponseBean buildingdelete(String parameter) {
        ResponseBean responseBean= new ResponseBean<>();
        Building  building= new Building();
        JSONObject jsonobject = JSONObject.parseObject(parameter);
        Integer id= jsonobject.getInteger("id");
        QueryWrapper<Building> buildingtWrapper = new QueryWrapper<>();
        buildingtWrapper.lambda().eq(Building::getBuildingId,id);
        Building bui= buildingMapper.selectOne(buildingtWrapper);

        if (bui.getStatus().equals(2)){
            responseBean.addSuccess("楼盘已发布不可以删除");
            return responseBean;
        }
        QueryWrapper<Building> buildingIdQueryWrapper = new QueryWrapper<>();
        buildingIdQueryWrapper.eq("building_id", id);
        building.setBuildingId(String.valueOf(id));
        building.setStatus(-1);
        buildingMapper.update(building,buildingIdQueryWrapper);
        ResponseBean ResponseBean= new ResponseBean<>();
        ResponseBean.addSuccess("成功");
        return ResponseBean;
    }


}
