package com.example.wholeestate.service.impl;

import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.example.wholeestate.common.Constant;
import com.example.wholeestate.common.resp.ResponseBean;
import com.example.wholeestate.common.uuid.IdGen;
import com.example.wholeestate.dao.CustomerMapper;

import com.example.wholeestate.model.Building;
import com.example.wholeestate.model.Customer;
import com.example.wholeestate.service.ICustomerService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.time.LocalDateTime;
import java.util.HashMap;
import java.util.List;

/**
 * <p>
 *  服务实现类
 * </p>
 *
 * @author weiximei
 * @since 2019-03-20
 */
@Service
public class CustomerServiceImpl extends ServiceImpl<CustomerMapper, Customer> implements ICustomerService {

    @Autowired
    private CustomerMapper customerMapper;

    private IdGen idGen = IdGen.get();

    @Override
    public ResponseBean customerList(String parameter) {
        ResponseBean response= new ResponseBean();
        JSONObject object= JSONObject.parseObject(parameter);

        Integer pageNum = object.getInteger("pageNum");
        Integer pageSize = object.getInteger("pageSize");

        Page<Customer> page = new Page<>();
        page.setSize(pageSize == null ? 10 : pageSize);
        page.setCurrent(pageNum == null ? 1 : pageNum);
        IPage<Customer> customer= customerMapper.customerList(page);
        List<Customer> customerList=customer.getRecords();

        HashMap hashMap= new HashMap<>();
        hashMap.put("list",customerList);
        hashMap.put("total",customer.getTotal());
        hashMap.put("pageNum",customer.getCurrent());
        hashMap.put("pageSize",customer.getSize());
        response.addSuccess(hashMap);
        return response;
    }

    @Override
    public ResponseBean customerSelectId(Integer id) {
        ResponseBean response= new ResponseBean();
        QueryWrapper<Customer> customer=new QueryWrapper<>();
        customer.lambda().eq(Customer::getStatus,0);
        Customer customerList= customerMapper.selectOne(customer);
        response.addSuccess(customerList);
        return response;
    }

    @Override
    public ResponseBean registeredCustomer(String parameter) {
        ResponseBean responseBean = new ResponseBean();
        Customer customer = JSONObject.parseObject(parameter, Customer.class);
        customer.setCreateDate(LocalDateTime.now());
        customer.setStatus(1);

        customer.setCustomerId(idGen.nextId()+"");
        customerMapper.insert(customer);
        return responseBean;
    }

    @Override
    public ResponseBean getWXCustomer(String openid) {
        ResponseBean responseBean = new ResponseBean();
        QueryWrapper<Customer> customerQueryWrapper = new QueryWrapper<>();
        customerQueryWrapper.eq("openid", openid);
        Customer customer = customerMapper.selectOne(customerQueryWrapper);
        if (null == customer) {
            responseBean.addError(Constant.NOT_USER, "用户不存在!");
            return responseBean;
        }

        responseBean.addSuccess(customer);
        return responseBean;
    }
}
